Mangle Interpreter
A pure Rust interpreter for the Mangle Intermediate Representation (IR).
This crate enables the Edge Mode of execution, allowing Mangle programs to run on devices or in environments where a WebAssembly runtime is not available or desired.
It executes the Physical IR operations (Op) directly.
Usage
See mangle-driver for the high-level API to compile and execute source code.
Structs
- Interpreter
- A pure Rust interpreter for Mangle IR.
- MemStore
- A simple in-memory implementation of
Store. Supports semi-naive evaluation by tracking “stable” and “delta” facts. - Provenance
Entry - A record of one derivation: which fact was derived and which premises were used.
- Provenance
Recorder - Lightweight recorder that captures derivation provenance during execution.
Enums
Traits
- Store
- Abstract interface for relation storage (Edge Mode).