Interpreter

Struct Interpreter 

pub struct Interpreter<'a> { /* private fields */ }
A pure Rust interpreter for Mangle IR.

Implementations

Source

impl<'a> Interpreter<'a>

pub fn new(ir: &'a Ir, store: Box<dyn Store + 'a>) -> Self

pub fn with_provenance(self) -> Self

Enable provenance recording. When set, every successful insert records which premise facts were in the current environment.

pub fn store(&self) -> &dyn Store

Helper to get the underlying store (e.g. to inspect results).

pub fn store_mut(&mut self) -> &mut dyn Store

Helper to get the underlying store mutably.

pub fn into_store(self) -> Box<dyn Store + 'a>

Consumes the interpreter and returns the underlying store.

pub fn into_provenance(self) -> Option<ProvenanceRecorder>

Consume the interpreter, returning the provenance recorder if enabled.

pub fn into_parts(self) -> (Box<dyn Store + 'a>, Option<ProvenanceRecorder>)

Consume the interpreter, returning the store and optional provenance.

pub fn execute(&mut self, op: &Op) -> Result<usize>

Executes the operation and returns the number of facts inserted.